@@ -5,7 +5,9 @@ NULL
 #'
 #' Generate a portfolio of solutions for a conservation planning
 #' \code{\link{problem}} by randomly reordering the data prior to
-#' solving the problem ().
+#' solving the problem. This is recommended as a replacement for
+#' \code{\link{add_top_portfolio}} when the \emph{Gurobi} software is not
+#' available.
 #'
 #' @param x \code{\link{ConservationProblem-class}} object.
 #'
@@ -70,9 +72,6 @@ NULL
 #' @name add_shuffle_portfolio
 NULL
 
-#' @export
-methods::setClass("ShufflePortfolio", contains = "Portfolio")
-
 #' @rdname add_shuffle_portfolio
 #' @export
 add_shuffle_portfolio <- function(x, number_solutions = 10L, threads = 1L,
