@@ -8,8 +8,9 @@ NULL
 #' planning unit exhibits.
 #'
 #' @param x \code{\link[raster]{Raster-class}},
-#'   \code{\link[sp]{SpatialLines-class}}, or
-#'   \code{\link[sp]{SpatialPolygons-class}} object. If \code{x} is a
+#'   \code{\link[sp]{SpatialLines-class}},
+#'   \code{\link[sp]{SpatialPolygons-class}},
+#'   \code{\link[sf]{sf}} object representing planning units. If \code{x} is a
 #'   \code{\link[raster]{Raster-class}} object then it must have only one
 #'   layer.
 #'
@@ -21,13 +22,14 @@ NULL
 #'   each other and potentially reduce the processing time required to
 #'   generate the boundary matrices. This argument is only used when
 #'   the planning unit data are vector-based polygons (i.e.
-#'   \code{\link[sp]{SpatialPolygonsDataFrame}} objects). The default argument
+#'   \code{\link[sp]{SpatialPolygonsDataFrame}} objects). \strong{Note that
+#'   using \code{TRUE} may crash Mac OSX systems.} The default argument
 #'   is \code{FALSE}.
 #'
 #' @details This function returns a \code{\link[Matrix]{dsCMatrix-class}}
 #'   symmetric sparse matrix. Cells on the off-diagonal indicate the length of
 #'   the shared boundary between two different planning units. Cells on the
-#'   diagonal indicate length of a given planning unit"s edges that have no
+#'   diagonal indicate length of a given planning unit's edges that have no
 #'   neighbors (e.g. for edges of planning units found along the
 #'   coastline). \strong{This function assumes the data are in a coordinate
 #'   system where Euclidean distances accurately describe the proximity
@@ -51,16 +53,20 @@ NULL
 #' # subset data to reduce processing time
 #' r <- crop(sim_pu_raster, c(0, 0.3, 0, 0.3))
 #' ply <- sim_pu_polygons[c(1:2, 10:12, 20:22), ]
+#' ply2 <- st_as_sf(ply)
 #'
 #' # create boundary matrix using raster data
 #' bm_raster <- boundary_matrix(r)
 #'
-#' # create boundary matrix using polygon data
+#' # create boundary matrix using polygon (Spatial) data
 #' bm_ply1 <- boundary_matrix(ply)
 #'
-#' # create boundary matrix using polygon data and GEOS STR query trees
+#' # create boundary matrix using polygon (sf) data
+#' bm_ply2 <- boundary_matrix(ply2)
+#'
+#' # create boundary matrix with polygon (Spatial) data and GEOS STR query trees
 #' # to speed up processing
-#' bm_ply2 <- boundary_matrix(ply, TRUE)
+#' bm_ply3 <- boundary_matrix(ply, TRUE)
 #'
 #' # plot raster and boundary matrix
 #' \donttest{
@@ -72,10 +78,13 @@ NULL
 #' # plot polygons and boundary matrices
 #' \donttest{
 #' par(mfrow = c(1, 3))
-#' plot(r, main = "polygons", axes = FALSE, box = FALSE)
+#' plot(r, main = "polygons (Spatial)", axes = FALSE, box = FALSE)
 #' plot(raster(as.matrix(bm_ply1)), main = "boundary matrix", axes = FALSE,
 #'      box = FALSE)
-#' plot(raster(as.matrix(bm_ply2)), main = "boundary matrix (STR)",
+#' plot(r, main = "polygons (sf)", axes = FALSE, box = FALSE)
+#' plot(raster(as.matrix(bm_ply2)), main = "boundary matrix", axes = FALSE,
+#'      box = FALSE)
+#' plot(raster(as.matrix(bm_ply3)), main = "boundary matrix (Spatial, STR)",
 #'             axes = FALSE, box = FALSE)
 #' }
 #' @export
@@ -169,6 +178,24 @@ boundary_matrix.SpatialPoints <- function(x, str_tree = FALSE) {
     "see ?constraints alternative constraints")
 }
 
+#' @rdname boundary_matrix
+#' @method boundary_matrix sf
+#' @export
+boundary_matrix.sf <- function(x, str_tree = FALSE) {
+  assertthat::assert_that(inherits(x, "sf"))
+  geomc <- geometry_classes(x)
+  if (any(grepl("POINT", geomc, fixed = TRUE)))
+    stop("data represented by points have no boundaries - ",
+      "see ?constraints alternative constraints")
+  if (any(grepl("LINE", geomc, fixed = TRUE)))
+    stop("data represented by lines have no boundaries - ",
+      "see ?constraints alternative constraints")
+  if (any(grepl("GEOMETRYCOLLECTION", geomc, fixed = TRUE)))
+    stop("geometry collection data are not supported")
+  boundary_matrix(sf::as_Spatial(sf::st_set_crs(x, sf::st_crs(NA_character_))),
+                  str_tree = str_tree)
+}
+
 #' @rdname boundary_matrix
 #' @method boundary_matrix default
 #' @export
