@@ -4,69 +4,62 @@ NULL
 #' Feature by planning unit matrix
 #'
 #' Generate a matrix showing the amount of each feature in each planning
-#' unit (also known as an \emph{rij} matrix).Each row corresponds
-#' to a different feature and each column corresponds to a different feature.
+#' unit (also known as an \emph{rij} matrix).
 #'
-#' @param x \code{\link[raster]{Raster-class}} or
-#'   \code{\link[sp]{Spatial-class}} object representing the
-#'   planning units.
+#' @param x \code{\link[raster]{Raster-class}},
+#'   \code{\link[sp]{Spatial-class}}, or \code{\link[sf]{sf}} object
+#'   representing the planning units.
 #'
 #' @param y \code{\link[raster]{Raster-class}} object representing the
 #'   features.
 #'
-#' @param fun \code{function} for summarizing values inside each planning unit.
+#' @param fun \code{character} for summarizing values inside each planning unit.
 #'   This parameter is only used when the argument to \code{x} is a
-#'   \code{\link[sp]{Spatial-class}} object. Defaults to \code{sum}.
+#'   \code{\link[sp]{Spatial-class}} or \code{\link[sf]{sf}} object.
+#'   Defaults to \code{"sum"}.
 #'
-#' @param ... additional arguments passed to \code{\link{fast_extract}} if
-#'   argument to \code{x} inherits from a \code{\link[sp]{Spatial-class}}
-#'   object.
+#' @param ... not used.
 #'
-#' @details The sparse matrix represents the spatial intersection between the
-#'   planning units and the features. Rows correspond to planning units,
-#'   and columns correspond to features. Values correspond to the amount
-#'   of the feature in the planning unit. For example, the amount of the
-#'   third species in the second planning unit would be contained in the
-#'   cell in the third column and in the second column.
-#'
-#'   This function can take a long to run for big data sets. To reduce
-#'   processing time, the \code{\link{set_number_of_threads}} function
-#'   can be used to allocate more computational resources. Additionally,
-#'   dealing with planning units represented with
-#'   \code{\link[sp]{SpatialPolygonsDataFrame}} object, the
-#'   \code{\link[velox]{velox}} package can be installed to reduce
-#'   processing time.
-#'
-#'   Generally, processing \code{\link[sp]{Spatial-class}} data takes much
-#'   longer to process then \code{\link[raster]{Raster-class}} data, and
+#' @details
+#'   Generally, processing vector (i.e. \code{\link[sp]{Spatial-class}} or
+#'   \code{\link[sf]{sf}}) data takes much
+#'   longer to process then \code{\link[raster]{Raster-class}} data,
 #'   so it is recommended to use \code{\link[raster]{Raster-class}} data
 #'   for planning units where possible.
 #'
-#' @seealso \code{\link{set_number_of_threads}}, \code{\link[velox]{velox}}.
-#'
-#' @return \code{\link{Matrix}{dgCMatrix-class}} object.
+#' @return \code{\link[Matrix]{dgCMatrix-class}} sparse matrix object.
+#'   The sparse matrix represents the spatial intersection between the
+#'   planning units and the features. Rows correspond to planning units,
+#'   and columns correspond to features. Values correspond to the amount
+#'   of the feature in the planning unit. For example, the amount of the
+#'   third species in the second planning unit would be stored in the
+#'   third column and second row.
 #'
 #' @name rij_matrix
 #'
 #' @exportMethod rij_matrix
 #'
-#' @aliases rij_matrix,Raster,Raster-method rij_matrix,Spatial,Raster-method
+#' @aliases rij_matrix,Raster,Raster-method rij_matrix,Spatial,Raster-method rij_matrix,sf,Raster-method
 #'
 #' @examples
 #' # load data
-#' data(sim_pu_raster, sim_pu_polygons, sim_pu_zones_stack)
+#' data(sim_pu_raster, sim_pu_polygons, sim_pu_sf, sim_pu_zones_stack)
 #'
 #' # create rij matrix using raster layer planning units
 #' rij_raster <- rij_matrix(sim_pu_raster, sim_features)
 #' print(rij_raster)
 #'
-#' # create rij matrix using polygon planning units
+#' # create rij matrix using polygon (Spatial) planning units
 #' rij_polygons <- rij_matrix(sim_pu_polygons, sim_features)
 #' print(rij_polygons)
 #'
+#' # create rij matrix using polygon (sf) planning units
+#' rij_sf <- rij_matrix(sim_pu_sf, sim_features)
+#' print(rij_sf)
+#'
 #' # create rij matrix using raster stack planning units
-#' rij_raster <- rij_matrix(sim_pu_zones_stack, sim_features)
-#' print(rij_raster)
+#' rij_zones_raster <- rij_matrix(sim_pu_zones_stack, sim_features)
+#' print(rij_zones_raster)
 #' @export
 methods::setGeneric("rij_matrix",
                     signature = methods::signature("x", "y"),
@@ -107,7 +100,7 @@ methods::setMethod(
       }
     } else {
       # othewise, process each feature separately
-        m <- plyr::llply(seq_len(raster::nlayers(y)), .parallel = FALSE,
+        m <- lapply(seq_len(raster::nlayers(y)), .parallel = FALSE,
           function(i) {
             m <- matrix(y[[i]][][included], nrow = 1)
             m[is.na(m)] <- 0
@@ -125,10 +118,18 @@ methods::setMethod(
 methods::setMethod(
   "rij_matrix",
   signature(x = "Spatial", y = "Raster"),
-  function(x, y, fun = sum, ...) {
-    m <- fast_extract(x = y, y = x, df = FALSE, sp = FALSE, fun = fun, ...)
-    if (raster::nlayers(y) == 1)
-      m <- matrix(m, ncol = 1)
+  function(x, y, fun = "sum", ...) {
+    rij_matrix(sf::st_as_sf(x), y, fun = fun, ...)
+})
+
+#' @name rij_matrix
+#' @usage \S4method{rij_matrix}{sf,Raster}(x, y, fun, ...)
+#' @rdname rij_matrix
+methods::setMethod(
+  "rij_matrix",
+  signature(x = "sf", y = "Raster"),
+  function(x, y, fun = "sum", ...) {
+    m <- fast_extract(x = y, y = x, fun = fun)
     m[is.na(m[])] <- 0
     m <- methods::as(m, "dgCMatrix")
     colnames(m) <- names(y)
