@@ -47,7 +47,7 @@ test_that("solve (compressed formulation, single zone)", {
        add_max_utility_objective(budget = budget) %>%
        add_locked_in_constraints(locked_in) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s1 <- solve(p)
   s2 <- solve(p)
@@ -119,7 +119,7 @@ test_that("solve (expanded formulation, single zone)", {
        add_max_utility_objective(budget = budget) %>%
        add_locked_in_constraints(locked_in) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
@@ -185,7 +185,7 @@ test_that("compile (compressed formulation, multiple zones, scalar budget)", {
   for (z in seq_len(n_z)) {
     for (f in seq_len(n_f)) {
       counter <- counter + 1
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
       m[counter, (n_z * n_pu) + ((z - 1) * n_f) + f] <- -1
     }
   }
@@ -221,7 +221,7 @@ test_that("solve (compressed formulation, multiple zones, scalar budget)", {
        add_manual_locked_constraints(data.frame(pu = c(1, 2),
                                                 zone = c("2", "2"),
                                                 status = c(0, 1))) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test that solution is correct
@@ -281,7 +281,7 @@ test_that("compile (expanded formulation, multiple zones, scalar budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + ((z - 1) * n_f) + f
       m[counter, col] <- -1
@@ -319,7 +319,7 @@ test_that("solve (expanded formulation, multiple zones, scalar budget)", {
        add_manual_locked_constraints(data.frame(pu = c(1, 2),
                                                 zone = c("2", "2"),
                                                 status = c(0, 1))) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
@@ -359,7 +359,7 @@ test_that("compile (compressed formulation, multiple zones, vector budget)", {
   for (z in seq_len(n_z)) {
     for (f in seq_len(n_f)) {
       counter <- counter + 1
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
       m[counter, (n_z * n_pu) + ((z - 1) * n_f) + f] <- -1
     }
   }
@@ -399,7 +399,7 @@ test_that("solve (compressed formulation, multiple zones, vector budget)", {
        add_manual_locked_constraints(data.frame(pu = c(1, 2),
                                                 zone = c("2", "2"),
                                                 status = c(0, 1))) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test that solution is correct
@@ -459,7 +459,7 @@ test_that("compile (expanded formulation, multiple zones, vector budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + ((z - 1) * n_f) + f
       m[counter, col] <- -1
@@ -501,7 +501,7 @@ test_that("solve (expanded formulation, multiple zones, vector budget)", {
        add_manual_locked_constraints(data.frame(pu = c(1, 2),
                                                 zone = c("2", "2"),
                                                 status = c(0, 1))) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
