@@ -48,7 +48,7 @@ test_that("solution (compressed formulation, single zone)", {
         add_locked_in_constraints(locked_in) %>%
         add_locked_out_constraints(locked_out) %>%
         add_absolute_targets(c(2, 10)) %>%
-        add_default_solver(gap = 0)
+        add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s1 <- solve(p)
   s2 <- solve(p)
@@ -121,7 +121,7 @@ test_that("solution (expanded formulation, single zone)", {
         add_locked_in_constraints(locked_in) %>%
         add_locked_out_constraints(locked_out) %>%
         add_absolute_targets(c(2, 10)) %>%
-        add_default_solver(gap = 0)
+        add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
@@ -192,7 +192,7 @@ test_that("compile (compressed formulation, multiple zones, scalar budget)", {
     f <- match(targs$feature[i], feature_names(sim_features_zones))
     counter <- counter + 1
     for (z in zs)
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
     m[counter, (n_z * n_pu) + i] <- 1
   }
   counter <- counter + 1
@@ -236,7 +236,7 @@ test_that("solve (compressed formulation, multiple zones, scalar budget)", {
        add_min_shortfall_objective(budget = budget) %>%
        add_manual_targets(targs) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test that solution is correct
@@ -304,7 +304,7 @@ test_that("compile (expanded formulation, multiple zones, scalar budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + i
       m[counter, col] <- 1
@@ -351,7 +351,7 @@ test_that("solve (expanded formulation, multiple zones, scalar budget)", {
        add_min_shortfall_objective(budget = budget) %>%
        add_manual_targets(targs) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
@@ -398,7 +398,7 @@ test_that("compile (compressed formulation, multiple zones, vector budget)", {
     f <- match(targs$feature[i], feature_names(sim_features_zones))
     counter <- counter + 1
     for (z in zs)
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
     m[counter, (n_z * n_pu) + i] <- 1
   }
   counter <- counter + 1
@@ -446,7 +446,7 @@ test_that("solve (compressed formulation, multiple zones, vector budget)", {
        add_min_shortfall_objective(budget = budget) %>%
        add_manual_targets(targs) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test that solution is correct
@@ -514,7 +514,7 @@ test_that("compile (expanded formulation, multiple zones, vector budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + i
       m[counter, col] <- 1
@@ -565,7 +565,7 @@ test_that("solve (expanded formulation, multiple zones, vector budget)", {
        add_min_shortfall_objective(budget = budget) %>%
        add_manual_targets(targs) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test that solution is correct
